#
# spec file for package molsketch
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define srcname Molsketch
%define sover 1
%define soname -qt5-%{sover}
%define binname %{name}-qt5
Name:           molsketch
Version:        0.5.1
Release:        lp152.4.5
Summary:        2D molecular structures editor
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Chemistry
URL:            https://molsketch.sourceforge.net
Source0:        https://downloads.sourceforge.net/molsketch/Molsketch-%{version}-src.tar.gz
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
%if 0%{suse_version} >= 1550 || 0%{?sle_version} >= 150200
BuildRequires:  rsvg-convert
%else
BuildRequires:  rsvg-view
%endif
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(openbabel-2.0)

%description
The purpose of this editor to help drawing molecules.
Features:
 * open, save and import in all formats supported by the OpenBabel library
 * export to Scalable Vector Graphics (SVG) and a number of common used bitmap
   formats
 * print and export your document to PDF

%package -n     lib%{name}%{soname}
Summary:        C++ library for %{name}
Group:          System/Libraries
Provides:       libobabeliface%{soname} = %{version}

%description -n lib%{name}%{soname}
2D molecular structures editor.

This package provides the shared libraries.

%package 	    devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{soname} = %{version}
%if %{with qt4}
Requires:       libqt4-devel-doc
%else
Requires:       libqt5-qttools
%endif

%description 	devel
2D molecular structures editor.

This package contains header files and libraries needed to develop
application that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
2D molecular structures editor.

Help documentation for %{name}.

%prep
%setup -q -n %{srcname}-%{version}

dos2unix -k doc/cs/molsketch.adp

%build
%cmake \
  -DMSK_INSTALL_PREFIX=%{_prefix} \
  -DMSK_INSTALL_DOCS=%{_docdir}/%{name} \
  -DMSK_INSTALL_INCLUDES=%{_includedir}

%make_jobs

%install
%cmake_install

for sz in 24 32 48 64 128 256 512
do
  rsvg-convert -o %{name}-${sz}.png -w ${sz} molsketch/images/molsketch.svg
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${sz}x${sz}/apps
  install -m0644 %{name}-${sz}.png %{buildroot}%{_datadir}/icons/hicolor/${sz}x${sz}/apps/%{name}.png
done

%suse_update_desktop_file -c %{name} %{name} "2D molecular structures editor" %{binname} %{name} Education Chemistry

%fdupes -s %{buildroot}%{_datadir}

%post -n lib%{name}%{soname} -p /sbin/ldconfig
%postun -n lib%{name}%{soname} -p /sbin/ldconfig

%if 0%{?suse_version} <= 1320
%post
%icon_theme_cache_post
%desktop_database_post
%mime_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun
%mime_database_postun
%endif

%files
%license COPYING
%doc CHANGELOG
%{_bindir}/%{binname}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/molsketch.*
%{_datadir}/pixmaps/molsketch.xpm
%exclude %{_docdir}/%{name}/cs/
%exclude %{_docdir}/%{name}/en/
%exclude %{_docdir}/%{name}/nl/
%{_datadir}/icons/hicolor/scalable/mimetypes/application-x-molsketch.svg
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/net.sourceforge.molsketch.appdata.xml
%{_datadir}/mime/packages/molsketch.xml

%files -n lib%{name}%{soname}
%{_libdir}/lib%{name}*so.*
%{_libdir}/libobabeliface*so.*

%files devel
%{_libdir}/lib%{name}*so
%{_libdir}/libobabeliface*so

%files doc
%{_docdir}/%{name}/cs/
%{_docdir}/%{name}/en/
%{_docdir}/%{name}/nl/

%changelog
* Thu Feb 20 2020 Max Lin <mlin@suse.com>
- Leap 15.2 and SLE15 SP2 has newer librsvg, extend the conditional
  for "BuildRequires: rsvg-convert"
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Tue Jan  9 2018 badshah400@gmail.com
- Update to version 0.5.1.
  * Newman radius of atom to draw Newman-type projections.
  * New tools for aligning, spacing, and cleaning up molecules.
  * Better encapsulate calls to OpenBabel to avoid crashes.
  * Several fixes to qmake/cmake installation of files (including
    MIME types).
- Drop molsketch-cmake-incorrect-file-loc.patch: incorporated
  upstream.
- Use rsvg-convert instead of inkscape for the svg-to-png
  conversion of icons; reduces the large number of build
  dependencies otherwise required for inkscape alone.
- Only run post(un) scriptlets for openSUSE <= 1320; for newer
  openSUSE these are automatically taken care of by rpm triggers;
  where applicable also run mime_database_post(un) as part of
  these scriptlets since molsketch now installs a mime file.
* Fri Dec 29 2017 jengelh@inai.de
- Trim (tm) symbol. Trim filler wording from description.
* Mon Oct  9 2017 badshah400@gmail.com
- Update to version 0.5.0:
  * Change log displayed on startup.
  * Lone pairs and radical electrons.
  * Selection by type (not yet really useful as properties are
    usually edited only for single items).
  * Querying Wikidata for chemical structures (requires
    OpenBabel and InChI support).
- Add molsketch-cmake-incorrect-file-loc.patch: Fix cmake install
  command looking for files in molsketch/src/* whereas they have
  been moved to molsketch/* already
- Build against Qt5 unconditionally (the minimum Qt5 is available
  across all supported openSUSE versions).
- Adapt file list for update: include files no longer installed
* Thu Aug 17 2017 badshah400@gmail.com
- Update to 0.4.1:
  * A new text tool.
  * Cmake build now offers the option to turn off OpenBabel
    support, which was previously only possible with qmake.
  * Legacy stereo bonds (from files created with versions prior to
    Lithium) are now imported correctly.
- Use inkscape to build hicolor png icons from bundled svg image
  and install then all.
- Run post install scripts to update desktop database and hicolor
  icon theme.
- Run spec-cleaner for a clean-up.
* Thu Oct 22 2015 avvissu@yandex.ru
- Update to 0.3.0:
  * see: /usr/share/doc/packages/molsketch/CHANGELOG
- Create a new spec file for building RPM
- Use qmake instead of cmake
- Add new packages: libmolsketch, molsketch-doc, molsketch-devel
* Sat Jul  7 2012 scorot@free.fr
- fix build on SLE 11
* Sat Jul  7 2012 scorot@free.fr
- fix openbabel dependency according to package name changes
* Sat Feb 25 2012 mailaender@opensuse.org
- update to version 2.0.0 with fixes from git by the developer
* Tue Feb 21 2012 mailaender@opensuse.org
- initial packaging, added QtAssistant include path to CMakeLists.txt, added BuildRequires: -post-build-checks because of compiler warnings
